==> qtjambi-datavisualization-debuginfo-macos-5.15.17.jar: sources/QtJambiDataVisualization/Q3DInputHandler_shell.h <==
#ifndef Q3DINPUTHANDLER_SHELL_H
#define Q3DINPUTHANDLER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDataVisualization/q3dinputhandler.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtDataVisualization/qabstract3dinputhandler.h>
#include <QtGui/qevent.h>
#include <QtJambi/RegistryAPI>


class Q3DInputHandler_shell : public QtDataVisualization::Q3DInputHandler, public QtJambiShellInterface
{
public:
    Q3DInputHandler_shell(QObject* parent0 = nullptr);
    ~Q3DInputHandler_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0, const QPoint& mousePos1) override;
    void mousePressEvent(QMouseEvent* event0, const QPoint& mousePos1) override;
    void mouseReleaseEvent(QMouseEvent* event0, const QPoint& mousePos1) override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* event0) override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct Q3DInputHandler_access : public QtDataVisualization::Q3DInputHandler
{
    void __qt_mouseMoveEvent_QMouseEvent_ptr_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID mousePos1);
    void __qt_mousePressEvent_QMouseEvent_ptr_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID mousePos1);
    void __qt_mouseReleaseEvent_QMouseEvent_ptr_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID mousePos1);
    void __qt_wheelEvent_QWheelEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
};

#endif // Q3DINPUTHANDLER_SHELL_H

==> qtjambi-datavisualization-debuginfo-macos-6.5.3.jar: sources/QtJambiDataVisualization/Q3DInputHandler_shell.h <==
#ifndef Q3DINPUTHANDLER_SHELL_H
#define Q3DINPUTHANDLER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDataVisualization/q3dinputhandler.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDataVisualization/q3dscene.h>
#include <QtDataVisualization/qabstract3dinputhandler.h>
#include <QtGui/qevent.h>
#include <QtJambi/RegistryAPI>


class Q3DInputHandler_shell : public Q3DInputHandler, public QtJambiShellInterface
{
public:
    Q3DInputHandler_shell(QObject* parent0 = nullptr);
    ~Q3DInputHandler_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void mouseDoubleClickEvent(QMouseEvent* event0) override;
    void mouseMoveEvent(QMouseEvent* event0, const QPoint& mousePos1) override;
    void mousePressEvent(QMouseEvent* event0, const QPoint& mousePos1) override;
    void mouseReleaseEvent(QMouseEvent* event0, const QPoint& mousePos1) override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* event0) override;
    void wheelEvent(QWheelEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct Q3DInputHandler_access : public Q3DInputHandler
{
    void __qt_mouseMoveEvent_QMouseEvent_ptr_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID mousePos1);
    void __qt_mousePressEvent_QMouseEvent_ptr_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID mousePos1);
    void __qt_mouseReleaseEvent_QMouseEvent_ptr_cref_QPoint(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID mousePos1);
    void __qt_wheelEvent_QWheelEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
};

#endif // Q3DINPUTHANDLER_SHELL_H
